//
//  AppDelegate.m
//  wxworksdktest
//
//  Created by WXWork on 16/5/25.
//  Copyright © 2016年 tencent. All rights reserved.
//

#import "AppDelegate.h"
#import "WWKApi.h"

@interface AppDelegate () <WWKApiDelegate>

@end

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    /*! @brief 以第三方应用的形式进行注册，需要先在管理端进行注册，获取到第三方应用的appid
     *
     * @param appId   第三方应用的appid
     * @param schema  当前app的schema
     */
    // [WWKApi registerAppID:@"wxworksdktest" schema:@"wwauth3rdtest"];
    
    //NSDictionary *dict = @{@"appId" : appId, @"corpId" : corpId, @"agentId" : agentId};
  
    NSInteger test_version = [[[NSUserDefaults standardUserDefaults] objectForKey:@"WWKApiTestVersion"] integerValue];
    if (test_version == WWKApiTestVersionUserAuth) {
        [WWKApi registerAppID:@"ww7b5e9c18599a5a3e" schema:@"wwauth3rd7b5e9c18599a5a3e"];
    } else if (test_version == WWKApiTestVersionCustomizeApp) {
        NSDictionary *dict = [[NSUserDefaults standardUserDefaults] dictionaryForKey:@"regist_app_info"];
        [WWKApi registerApp:[dict valueForKey:@"appId"]  corpId:[dict valueForKey:@"corpId"] agentId:[dict valueForKey:@"agentId"]];
    } else {
        [WWKApi registerAppID:@"wxb7ab197960934211" schema:@"wwauth3rdtest"];
    }
    [WWKApi updateSessionKeyIfNeeded:YES];
    // 第三方应用注册
    return YES;
}

- (void)applicationWillResignActive:(UIApplication *)application {
}

- (void)applicationDidEnterBackground:(UIApplication *)application {
}

- (void)applicationWillEnterForeground:(UIApplication *)application {
}

- (void)applicationDidBecomeActive:(UIApplication *)application {
}

- (void)applicationWillTerminate:(UIApplication *)application {
}

- (BOOL)application:(UIApplication *)application handleOpenURL:(NSURL *)url {
    return [self handleOpenURL:url sourceApplication:nil];
}

- (BOOL)application:(UIApplication *)application openURL:(NSURL *)url sourceApplication:(nullable NSString *)sourceApplication annotation:(id)annotation {
    return [self handleOpenURL:url sourceApplication:sourceApplication];
}

- (BOOL)handleOpenURL:(NSURL *)url sourceApplication:(NSString *)sourceApplication {
    /*! @brief 处理外部调用URL的时候需要将URL传给SDK进行相关处理
     * @param url 外部调用传入的url
     * @param delegate 当前类需要实现WWKApiDelegate对应的方法
     */
//    NSURLComponents *components = [[NSURLComponents alloc] initWithString:url.absoluteString];
//    __block BOOL useUrlData = NO;
    
    
    NSMutableDictionary *paramDict = [NSMutableDictionary dictionary];
    NSURLComponents * components = [[NSURLComponents alloc] initWithURL:url resolvingAgainstBaseURL:NO];
    for (NSURLQueryItem *item in components.queryItems) {
        paramDict[item.name] = item.value;
    }
    
    NSInteger appenv = [paramDict[@"appenv"] integerValue];
    BOOL useUrlData = [paramDict[@"surl"] integerValue] == 1;
    
    [[NSUserDefaults standardUserDefaults] setObject:@(useUrlData) forKey:[NSString stringWithFormat:@"wxwork_enable_url_data_%ld",(long)appenv]];
    [[NSUserDefaults standardUserDefaults] synchronize];
    return [WWKApi handleOpenURL:url delegate:self];
}

- (void)onSessionKeyUpdate:(NSString *)newSessionKey{
    NSLog(@"onSessionKeyUpdate %@",newSessionKey);
    NSLog(@"sessionKey refresh:sdk update key %@",newSessionKey);
    [WWKApi setSessionKey:newSessionKey];
    __weak __typeof(self)weakSelf = self;
    [WWKApi initOpenData:^(BOOL isSucc) {
        [weakSelf showInitOpenDataResult:isSucc];
    }];
}

- (void)onResp:(WWKBaseResp *)resp {
    /*! @brief 所有通过sendReq发送的SDK请求的结果都在这个函数内部进行异步回调
     * @param resp SDK处理请求后的返回结果 需要判断具体是哪项业务的回调
     */
    NSMutableString *extra = [NSMutableString string];
    [self showRespLog:resp];
    /* 选择联系人(邮箱)的回调 */
    if ([resp isKindOfClass:[WWKPickContactResp class]]) {
        WWKPickContactResp *r = (WWKPickContactResp *)resp;
        for (int i = 0; i < MIN(r.contacts.count, 5); ++i) {
            if (extra.length) [extra appendString:@"\n"];
            [extra appendFormat:@"%@<%@>", [r.contacts[i] name], [r.contacts[i] email]];
        }
        if (r.contacts.count > 5) {
            [extra appendString:@"\n…"];
        }
    }
    
    /* SSO的回调 */
    if ([resp isKindOfClass:[WWKSSOResp class]]) {
        WWKSSOResp *r = (WWKSSOResp *)resp;
        [extra appendFormat:@"%@ for %@", r.code, r.state];
        __weak __typeof(self)weakSelf = self;
        dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
            [weakSelf fetchsessionKey:r.code];
        });
        NSLog(@"%@",extra);
        [self.logs appendString:extra];
        return;
        
    }
    
    /* WWKSelectPrivilegedContact的回调 */
    if ([resp isKindOfClass:[WWKSelectPrivilegedContactResp class]]) {
        WWKSelectPrivilegedContactResp *r = (WWKSelectPrivilegedContactResp *)resp;
        [extra appendFormat:@"selectedTicket : %@ for openUserIdList : %@ count : %ld expiresIn : %ld", r.selectedTicket, r.openUserIdList,r.selectedUserCount,r.expiresIn];
        NSLog(@"%@",extra);
        if (resp.errCode == 0) {
            self.openUserIdList = r.openUserIdList;
            self.selectedTicket = r.selectedTicket;
        }
        [self.logs appendString:extra];
        return;
    }
    
//    /* WWKCreateChatWithMsgResp的回调 */
//    if ([resp isKindOfClass:[WWKCreateChatWithMsgResp class]]) {
//        WWKCreateChatWithMsgResp *r = (WWKCreateChatWithMsgResp *)resp;
//        [extra appendFormat:@"WWKCreateChatWithMsgResp : %@", r.chatId];
//        NSLog(@"%@",extra);
//        if (resp.errCode == 0) {
//            self.chatid = r.chatId;
//        }
//        [self.logs appendString:extra];
//        return;
//    }
    
    /* 选择联系人(新接口)的回调 */
    if ([resp isKindOfClass:[WWKSelectContactResp class]]) {
        WWKSelectContactResp *r = (WWKSelectContactResp *)resp;
        
        // 保存一下选的人，用来创建群聊
        NSMutableArray *userOpenidList = [NSMutableArray new];
        for (WWKOpenIdInfo *openidInfo in r.openids) {
            if (openidInfo.idType == WWKOpenIdTypeUser) {
                [userOpenidList addObject:openidInfo.openid];
            }
        }
        self.userOpenidList = userOpenidList;
        
        // 延时一会儿再请求数据，防止app还处在background状态就去请求网络，导致网络层报NSPOSIXErrorDomain Code=53错误
        dispatch_after(dispatch_time(DISPATCH_TIME_NOW, (int64_t)(0.5 * NSEC_PER_SEC)), dispatch_get_main_queue(), ^{
            [self fetchContacts:r.openids];
        });
        
        [extra appendFormat:@"选人数 %lu", (unsigned long)[r.openids count]];
        NSLog(@"%@",extra);
        [self.logs appendString:extra];
        return;
    } /*else if([resp isKindOfClass:[WWKSelectUserDialTicketResp class]]) {
        WWKSelectUserDialTicketResp *r = (WWKSelectUserDialTicketResp *)resp;
        UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"返回结果"
                                                                                 message:[NSString stringWithFormat:@"errcode: %d", r.errCode]
                                                                          preferredStyle:(UIAlertControllerStyleAlert)];

        [alertController addTextFieldWithConfigurationHandler:^(UITextField *_Nonnull textField) {
            textField.text = [NSString stringWithFormat:@"openUserIdList: %@", [r.openUserIdList componentsJoinedByString:@","]];
        }];
        [alertController addTextFieldWithConfigurationHandler:^(UITextField *_Nonnull textField) {
            textField.text = [NSString stringWithFormat:@"selectedTicket: %@", r.selectedTicket];
        }];

        [alertController addTextFieldWithConfigurationHandler:^(UITextField *_Nonnull textField) {
            textField.text = [NSString stringWithFormat:@"expiresIn: %u", r.expiresIn];
        }];
        [alertController addAction:[UIAlertAction actionWithTitle:@"确定"
                                                            style:(UIAlertActionStyleCancel)handler:^(UIAlertAction *_Nonnull action) {
                                                                  }]];

        [[[[UIApplication sharedApplication] keyWindow] rootViewController] presentViewController:alertController animated:YES completion:nil];
        return;
    }*/
    
    /* 选择联系人(新接口)的回调 */
    if ([resp isKindOfClass:[WWKOpenChatWithMessageResp class]]) {
        [extra appendFormat:@"(创建新群聊)"];
    }
    if (extra.length) [extra insertString:@"\n\n" atIndex:0];
    [extra appendFormat:@"\nserializedDict : %@", resp.serializedDict];
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"返回结果" message:[NSString stringWithFormat:@"错误码：%d\n错误信息：%@%@", resp.errCode, resp.errStr, extra] preferredStyle:UIAlertControllerStyleAlert];
    [alert addAction:[UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:nil]];
    [[[[UIApplication sharedApplication] keyWindow] rootViewController] presentViewController:alert animated:YES completion:nil];
    [self.logs appendString:extra];
}

/* code换取sessionKey */
- (void)fetchsessionKey:(NSString *)code {
    NSURLSession *session = [NSURLSession sharedSession];
    BOOL auth = [[[NSUserDefaults standardUserDefaults] objectForKey:@"WWKApiTestVersion"] integerValue] == WWKApiTestVersionUserAuth;
    NSString *urlstr;
    if (auth) {
        urlstr =
            [NSString stringWithFormat:@"https://service-p8b9q9fu-1252892512.gz.apigw.tencentcs.com/release/"
                                       @"getuserinfo3rd?code=%@&appid=ww7b5e9c18599a5a3e&secret=yT7YWHWJRddm823FR7ZbJy166EeqbyO2acbmsYOaCb4",
                                       code];
    } else {
        urlstr =
            [NSString stringWithFormat:@"https://service-p8b9q9fu-1252892512.gz.apigw.tencentcs.com/release/"
                                       @"getuserinfo3rd?code=%@&appid=wxb7ab197960934211&secret=c1dN3dT9s8UvpZSeuKxGIF5PiORLFjaF8C8SxEznDpk",
                                       code];
    }

    NSURL *url = [NSURL URLWithString:urlstr];
    NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:url];
    request.HTTPMethod = @"GET";
    __weak __typeof(self) weakSelf = self;
    NSURLSessionDataTask *dataTask =
        [session dataTaskWithRequest:request
                   completionHandler:^(NSData *_Nullable data, NSURLResponse *_Nullable response, NSError *_Nullable error) {
                       NSError *jsonError;
                       NSDictionary *dict = [NSJSONSerialization JSONObjectWithData:data ?: [NSData data]
                                                                            options:NSJSONReadingMutableContainers
                                                                              error:&jsonError];
                       if ((!error) && (!jsonError)) {
                           [weakSelf showStringLog:[NSString stringWithFormat:@"fetchsessionKey code:%@ response:%@", code, dict]];
                           if ([dict[@"errcode"] integerValue] == 0) {
                               weakSelf.openUserid = dict[@"open_userid"];
                               [WWKApi setSessionKey:dict[@"session_key"]]; // 设置sessionKey
                               [WWKApi initOpenData:^(BOOL isSucc) {        // 初始化OpenData
                                   [weakSelf showInitOpenDataResult:isSucc];
                               }];
                           }
                       }
                   }];
    [dataTask resume];
}


/* 查询联系人详情 */
-(void)fetchContacts:(NSArray<WWKOpenIdInfo *> *)openids{
    __weak __typeof(self)weakSelf = self;
    
    NSMutableArray<WWKOpenDataItem *> *WWKOpenDataItemList = [NSMutableArray new];
    for (WWKOpenIdInfo *openIdInfo in openids) {
        
        if (openIdInfo.idType == WWKOpenIdTypeDepartment) {
            WWKOpenDataItem *item = [WWKOpenDataItem new];
            item.openid = openIdInfo.openid;
            item.type = @"departmentName";
            [WWKOpenDataItemList addObject:item];
        } else if (openIdInfo.idType == WWKOpenIdTypeUser){
            WWKOpenDataItem *itemName = [WWKOpenDataItem new];
            itemName.openid = openIdInfo.openid;
            itemName.type = @"userName";
            [WWKOpenDataItemList addObject:itemName];
            
            WWKOpenDataItem *itemDepartment = [WWKOpenDataItem new];
            itemDepartment.openid = openIdInfo.openid;
            itemDepartment.type = @"userDepartment";
            [WWKOpenDataItemList addObject:itemDepartment];
            
            WWKOpenDataItem *itemGender = [WWKOpenDataItem new];
            itemGender.openid = openIdInfo.openid;
            itemGender.type = @"userGender";
            [WWKOpenDataItemList addObject:itemGender];
        }
    }
    
    [WWKApi getOpenData:WWKOpenDataItemList completion:^(NSError *error, NSArray<WWKOpenDataItem *> *dataArray) {
        if (error) {
            [weakSelf fetchContactsResult:[NSString stringWithFormat:@"错误：%@",error]];
            return;
        }
        NSMutableDictionary *result = [NSMutableDictionary new];
        for (WWKOpenDataItem *openDataItem in dataArray) {
            NSMutableString *info = [[result objectForKey:openDataItem.openid]?:@"" mutableCopy];
            [info appendFormat:@"%@:%@ ",openDataItem.type,openDataItem.data];
            [result setObject:info forKey:openDataItem.openid];
        }
        [weakSelf fetchContactsResult:[[result allValues] componentsJoinedByString:@"、"]];
    }];
}

/* 结果展示 */
-(void)showInitOpenDataResult:(BOOL)isSucc{
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"InitOpenData结果" message:isSucc?@"成功":@"失败" preferredStyle:UIAlertControllerStyleAlert];
    [alert addAction:[UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:nil]];
    [[[[UIApplication sharedApplication] keyWindow] rootViewController] presentViewController:alert animated:YES completion:nil];
}

-(void)fetchContactsResult:(NSString *)result{
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"选人结果" message:result preferredStyle:UIAlertControllerStyleAlert];
    [alert addAction:[UIAlertAction actionWithTitle:@"确定" style:UIAlertActionStyleDefault handler:nil]];
    [[[[UIApplication sharedApplication] keyWindow] rootViewController] presentViewController:alert animated:YES completion:nil];
}


-(void)showRespLog:(WWKBaseResp *)resp{
    
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateFormat:@"YYYY-MM-dd HH:mm:ss"];
    NSDate *datenow = [NSDate date];
    NSString *currentTimeString = [formatter stringFromDate:datenow];
    NSString *respString = [NSString stringWithFormat:@"\n %@ %@ code:%d msg:%@\n 更多:",currentTimeString,NSStringFromClass([resp class]),resp.errCode,resp.errStr];
    [self.logs appendString:respString];
    
}

-(void)showStringLog:(NSString *)string{
    
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init];
    [formatter setDateFormat:@"YYYY-MM-dd HH:mm:ss"];
    NSDate *datenow = [NSDate date];
    NSString *currentTimeString = [formatter stringFromDate:datenow];
    NSString *respString = [NSString stringWithFormat:@"\n %@ %@",currentTimeString,string];
    [self.logs appendString:respString];
    
}

-(NSMutableString *)logs{
    if (!_logs) {
        _logs = [NSMutableString new];
    }
    return _logs;
}
@end
