//
//  ViewController.m
//  wxworksdktest
//
//  Created by WXWork on 16/5/25.
//  Copyright © 2016年 tencent. All rights reserved.
//

//#define INCLUDE_PRIVATE_API

#import "ViewController.h"
#import "WWKApi.h"
#import "AppDelegate.h"
#import <WebKit/WebKit.h>

extern NSString *WWKAPP_SCHEME;

typedef NS_ENUM(NSInteger, WWKApiRole) {
    WWKApiRolePersonal,
    WWKApiRoleCorp,
    WWKApiRoleServiceProvider
};

typedef NS_ENUM(NSInteger, WWKApiFunction) {
    WWKApiSSO,
    WWKApiShareText,
    WWKApiShareWeApp,
    WWKApiShareFile,
    WWKApiShareImage,
    WWKApiShareVideo,
    WWKApiShareLink,
    WWKApiShareLinkCustom,
    WWKApiShareForward,
    WWKApiShareSPHFeed,
    WWKApiShareSPHTopic,
    WWKApiShareSPHProfile,
    WWKApiShareSPHCombine,
    WWKApiPickContact,
    WWKApiPickUsers,
    WWKApiPickUsersV2,
    WWKApiPickUserDialTicket,
    WWKApiPickUsersForTM,
    WWKShowLogs,
    WWKSetFreeGO,
    WWKNoPermossionExamp,
    WWKSDKRegister,
    WWKViewUrlDataStatus,
#ifdef INCLUDE_PRIVATE_API
    WWKPrivateApiShareWeAppNormal,
    WWKPrivateApiShareWeAppPrivateMessage,
#endif
};

@interface ViewController () <UITableViewDelegate, UITableViewDataSource>
@property (nonatomic, strong) IBOutlet UITableView *tableView;
@property (nonatomic, strong) NSArray<NSNumber *> *functions;
@end

@interface ActionCell : UITableViewCell
@property (nonatomic, strong) IBOutlet UILabel *label;
@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    self.functions = [self roleFunctions:WWKApiRolePersonal];
    self.tableView.tableFooterView = [UIView new];
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return self.functions.count;
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    ActionCell *cell = [tableView dequeueReusableCellWithIdentifier:@"item" forIndexPath:indexPath];
    cell.label.text = [self actionTitle:(WWKApiFunction)self.functions[indexPath.row].integerValue];
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    switch ((WWKApiFunction)self.functions[indexPath.row].integerValue) {
        case WWKApiSSO:
            [self SSO:tableView];
            break;
        case WWKApiShareText:
            [self shareText:tableView];
            break;
        case WWKApiShareWeApp:
            [self shareWeApp:tableView];
            break;
        case WWKApiShareFile:
            [self shareFile:tableView];
            break;
        case WWKApiShareImage:
            [self shareImage:tableView];
            break;
        case WWKApiShareVideo:
            [self shareVideo:tableView];
            break;
        case WWKApiShareLink:
            [self shareLink:tableView];
            break;
        case WWKApiShareLinkCustom:
            [self shareLinkCustom:tableView];
            break;
        case WWKApiShareForward:
            [self shareForward:tableView];
            break;
        case WWKApiShareSPHFeed:
            [self shareSPHFeed:tableView];
            break;
        case WWKApiShareSPHTopic:
            [self shareSPHTopic:tableView];
            break;
        case WWKApiShareSPHProfile:
            [self shareSPHProfile:tableView];
            break;
        case WWKApiShareSPHCombine:
            [self shareSPHCombine:tableView];
            break;
        case WWKApiPickContact:
            [self pickContact:tableView];
            break;
        case WWKApiPickUsers:
            [self pickUsers:tableView];
            break;
        case WWKApiPickUsersV2:
            [self pickUsersV2:tableView];
            break;
        case WWKApiPickUserDialTicket:
            [self pickUserDialTickt:tableView];
            break;
        case WWKApiPickUsersForTM:
            [self pickUsersForTM:tableView];
            break;
        case WWKShowLogs:
            [self showLogs:tableView];
            break;
        case WWKSetFreeGO:
            [self setFreeGO:tableView];
            break;
        case WWKNoPermossionExamp:
            [self noPermission:tableView];
            break;
        case WWKSDKRegister:
            [self sdkRegister:tableView];
            break;
        case WWKViewUrlDataStatus:
            [self urlDataSatus];
            break;
#ifdef INCLUDE_PRIVATE_API
        case WWKPrivateApiShareWeAppNormal:
            [self shareWeAppNormal:tableView];
            break;
        case WWKPrivateApiShareWeAppPrivateMessage:
            [self ShareWeAppPrivateMessage:tableView];
            break;
#endif
    }
}

- (IBAction)roleSelect:(id)sender {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"选择应用类型" message:nil preferredStyle:UIAlertControllerStyleActionSheet];
    [alert addAction:[UIAlertAction actionWithTitle:@"个人应用" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        self.functions = [self roleFunctions:WWKApiRolePersonal];
        [self.tableView reloadData];
    }]];
    [alert addAction:[UIAlertAction actionWithTitle:@"企业应用" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        self.functions = [self roleFunctions:WWKApiRoleCorp];
        [self.tableView reloadData];
    }]];
    [alert addAction:[UIAlertAction actionWithTitle:@"服务商应用" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        self.functions = [self roleFunctions:WWKApiRoleServiceProvider];
        [self.tableView reloadData];
    }]];
    [alert addAction:[UIAlertAction actionWithTitle:@"取消" style:UIAlertActionStyleCancel handler:nil]];
    [self presentViewController:alert animated:YES completion:nil];
}

- (void)setApiTestVersion:(NSInteger)version {
    [[NSUserDefaults standardUserDefaults] setObject:@(version) forKey:@"WWKApiTestVersion"];
    [[NSUserDefaults standardUserDefaults] synchronize];

    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"版本已修改，重启生效"
                                                                   message:nil
                                                            preferredStyle:UIAlertControllerStyleActionSheet];
    [alert addAction:[UIAlertAction actionWithTitle:@"立即重启"
                                              style:UIAlertActionStyleDefault
                                            handler:^(UIAlertAction *_Nonnull action) {
                                                id a = @(1);
                                                [(NSString *)a length];
                                            }]];
    [self presentViewController:alert animated:YES completion:nil];
}

- (IBAction)schemeSelect:(id)sender {
    // UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"选择企业微信版本" message:nil preferredStyle:UIAlertControllerStyleActionSheet];
    // [alert addAction:[UIAlertAction actionWithTitle:@"通用版本" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
    //     WWKAPP_SCHEME = @"wxwork";
    // }]];
    // if ([[UIApplication sharedApplication] canOpenURL:[NSURL URLWithString:@"wxworkdebug:"]]) {
    //     [alert addAction:[UIAlertAction actionWithTitle:@"调试版本" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
    //         WWKAPP_SCHEME = @"wxworkdebug";
    //     }]];
    // }
    // if ([[UIApplication sharedApplication] canOpenURL:[NSURL URLWithString:@"wxworkrdm:"]]) {
    //     [alert addAction:[UIAlertAction actionWithTitle:@"蓝盾版本" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
    //         WWKAPP_SCHEME = @"wxworkrdm";
    //     }]];
    // }
    // if ([[UIApplication sharedApplication] canOpenURL:[NSURL URLWithString:@"wxworkrelease:"]]) {
    //     [alert addAction:[UIAlertAction actionWithTitle:@"发布版本" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
    //         WWKAPP_SCHEME = @"wxworkrelease";
    //     }]];
    // }


    NSInteger version = [[[NSUserDefaults standardUserDefaults] objectForKey:@"WWKApiTestVersion"] integerValue];
    if (version == 0) {
        version = WWKApiTestVersion3rdApp;
    }
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"选择企业微信SDK测试版本"
                                                                   message:nil
                                                            preferredStyle:UIAlertControllerStyleActionSheet];
    [alert addAction:[UIAlertAction actionWithTitle:(version == WWKApiTestVersion3rdApp) ? @"第三方独立应用测试(已选中)" : @"第三方独立应用测试"
                                              style:UIAlertActionStyleDefault
                                            handler:^(UIAlertAction *_Nonnull action) {
                                                WWKAPP_SCHEME = @"wxwork";
                                                [self setApiTestVersion:WWKApiTestVersion3rdApp];
                                            }]];

    [alert addAction:[UIAlertAction actionWithTitle:(version == WWKApiTestVersionUserAuth) ? @"员工授权测试(已选中)" : @"员工授权测试"
                                              style:UIAlertActionStyleDefault
                                            handler:^(UIAlertAction *_Nonnull action) {
                                                WWKAPP_SCHEME = @"wxwork";
                                                [self setApiTestVersion:WWKApiTestVersionUserAuth];
                                            }]];
    __weak typeof(self) weakSelf = self;
    [alert addAction:[UIAlertAction actionWithTitle:(version == WWKApiTestVersionCustomizeApp) ? @"自定义应用(已选中)" : @"自定义应用"
                                              style:UIAlertActionStyleDefault
                                            handler:^(UIAlertAction *_Nonnull action) {
                                                WWKAPP_SCHEME = @"wxwork";
                                                [weakSelf sdkRegister:nil];
                                            }]];

    if ([[UIApplication sharedApplication] canOpenURL:[NSURL URLWithString:@"wxworklocal:"]]) {
        [alert addAction:[UIAlertAction actionWithTitle:(version == WWKApiTestVersionLocalVersion) ? @"本地版本测试(已选中)" : @"本地版本测试"
                                                  style:UIAlertActionStyleDefault
                                                handler:^(UIAlertAction *_Nonnull action) {
                                                    WWKAPP_SCHEME = @"wxworklocal";
                                                    [self setApiTestVersion:WWKApiTestVersionLocalVersion];
                                                }]];
    }
    [alert addAction:[UIAlertAction actionWithTitle:@"取消" style:UIAlertActionStyleCancel handler:nil]];
    [self presentViewController:alert animated:YES completion:nil];
}

- (NSString *)actionTitle:(WWKApiFunction)func {
    switch (func) {
        case WWKApiSSO:
            return @"SSO";
        case WWKApiShareText:
            return @"分享文本";
        case WWKApiShareWeApp:
            return @"分享小程序";
        case WWKApiShareFile:
            return @"分享文件";
        case WWKApiShareImage:
            return @"分享图片";
        case WWKApiShareVideo:
            return @"分享视频";
        case WWKApiShareLink:
            return @"分享链接";
        case WWKApiShareLinkCustom:
            return @"分享自定义链接";
        case WWKApiShareForward:
            return @"分享聊天记录";
        case WWKApiShareSPHFeed:
            return @"分享视频号消息";
        case WWKApiShareSPHTopic:
            return @"分享视频号话题";
        case WWKApiShareSPHProfile:
            return @"分享视频号名片";
        case WWKApiShareSPHCombine:
            return @"分享视频号聊天记录";
        case WWKApiPickContact:
            return @"选择邮箱联系人";
        case WWKApiPickUsers:
            return @"选择联系人";
        case WWKApiPickUsersV2:
            return @"选择联系人V2";
        case WWKApiPickUserDialTicket:
            return @"腾会响铃选人";
            break;
        case WWKApiPickUsersForTM:
            return @"选择联系人For腾讯会议";
        case WWKShowLogs:
            return @"查看日志";
        case WWKSetFreeGO:
            return @"设置freego";
        case WWKNoPermossionExamp:
        return @"无权限案例";
        case WWKSDKRegister:
            return @"应用注册";
        case WWKViewUrlDataStatus:
            return @"查看url data 状态";
#ifdef INCLUDE_PRIVATE_API
        case WWKPrivateApiShareWeAppNormal:
            return @"私有api：分享小程序";
        case WWKPrivateApiShareWeAppPrivateMessage:
            return @"私有api：分享小程序（带私密消息）";
#endif
        default:
            return @"";
    }
}

- (NSArray<NSNumber *> *)roleFunctions:(WWKApiRole)role {
    switch (role) {
        case WWKApiRolePersonal:
            return @[
                @(WWKApiShareText),
                @(WWKApiShareWeApp),
                @(WWKApiShareFile),
                @(WWKApiShareImage),
                @(WWKApiShareVideo),
                @(WWKApiShareLink),
                @(WWKApiShareLinkCustom),
                @(WWKApiShareForward),
                @(WWKApiShareSPHFeed),
                @(WWKApiShareSPHTopic),
                @(WWKApiShareSPHProfile),
                @(WWKApiShareSPHCombine),
                @(WWKApiPickUsers),
                @(WWKApiPickUsersV2),
                @(WWKShowLogs),
                @(WWKSetFreeGO),
                @(WWKNoPermossionExamp),
                @(WWKViewUrlDataStatus),
#ifdef INCLUDE_PRIVATE_API
                @(WWKPrivateApiShareWeAppNormal),
                @(WWKPrivateApiShareWeAppPrivateMessage),
#endif
            ];
        case WWKApiRoleCorp:
            return @[
                @(WWKApiSSO),
                @(WWKApiShareText),
                @(WWKApiShareWeApp),
                @(WWKApiShareFile),
                @(WWKApiShareImage),
                @(WWKApiShareVideo),
                @(WWKApiShareLink),
                @(WWKApiShareLinkCustom),
                @(WWKApiShareForward),
                @(WWKApiShareSPHFeed),
                @(WWKApiShareSPHTopic),
                @(WWKApiShareSPHProfile),
                @(WWKApiShareSPHCombine),
                @(WWKApiPickContact),
                @(WWKApiPickUsers),
                @(WWKApiPickUsersV2),
                @(WWKApiPickUsersForTM),
                //@(WWKApiPickUserDialTicket),
                @(WWKShowLogs),
                @(WWKSetFreeGO),
                @(WWKNoPermossionExamp),
                @(WWKViewUrlDataStatus),
#ifdef INCLUDE_PRIVATE_API
                @(WWKPrivateApiShareWeAppNormal),
                @(WWKPrivateApiShareWeAppPrivateMessage),
#endif
            ];
        case WWKApiRoleServiceProvider:
            return @[
                @(WWKApiSSO),
                @(WWKApiShareText),
                @(WWKApiShareWeApp),
                @(WWKApiShareFile),
                @(WWKApiShareImage),
                @(WWKApiShareVideo),
                @(WWKApiShareLink),
                @(WWKApiShareLinkCustom),
                @(WWKApiShareForward),
                @(WWKApiShareSPHFeed),
                @(WWKApiShareSPHTopic),
                @(WWKApiShareSPHProfile),
                @(WWKApiShareSPHCombine),
                @(WWKApiPickContact),
                @(WWKApiPickUsers),
                @(WWKApiPickUsersV2),
                @(WWKShowLogs),
                @(WWKSetFreeGO),
                @(WWKNoPermossionExamp),
                @(WWKViewUrlDataStatus),
#ifdef INCLUDE_PRIVATE_API
                @(WWKPrivateApiShareWeAppNormal),
                @(WWKPrivateApiShareWeAppPrivateMessage),
#endif
            ];
    }
    return @[];
}

-(void)sendMessageToWWK:(WWKMessageAttachment *)attachment{
    BOOL isGroup = [[(AppDelegate*)[UIApplication sharedApplication].delegate userOpenidList] count] > 0;
    if (isGroup) {
        WWKOpenChatWithMessageReq *req = [[WWKOpenChatWithMessageReq alloc] init];
        req.attachment = attachment;
        req.userOpenidList = [(AppDelegate*)[UIApplication sharedApplication].delegate userOpenidList];
        req.openUserid = [(AppDelegate*)[UIApplication sharedApplication].delegate openUserid];
        [WWKApi sendReq:req completionHandler:^(WWKApiResponseErrorCode errorCode) {
            if (errorCode != WWKApiResponseErrorCodeOK) {
                [self onSendreqFailed];
            }
        }];
    } else {
        WWKSendMessageReq *req = [[WWKSendMessageReq alloc] init];
        req.attachment = attachment;
        [WWKApi sendReq:req completionHandler:^(WWKApiResponseErrorCode errorCode) {
            if (0 != errorCode) {
                [self onSendreqFailed];
            }
        }];
//        BOOL isGroupV2 = ([[(AppDelegate*)[UIApplication sharedApplication].delegate openUserIdList] count] > 0) || ([[(AppDelegate*)[UIApplication sharedApplication].delegate selectedTicket] length] > 0);
//        if (isGroupV2) {
//            WWKCreateChatWithMsgReq *req = [[WWKCreateChatWithMsgReq alloc] init];
//            req.loginOpenUserid = [(AppDelegate*)[UIApplication sharedApplication].delegate openUserid];
//            req.attachment = attachment;
//            req.selectedOpenUserIdList = [(AppDelegate*)[UIApplication sharedApplication].delegate openUserIdList];
//            req.selectedTicketList = @[[(AppDelegate*)[UIApplication sharedApplication].delegate selectedTicket]];
//            if (![WWKApi sendReq:req]) {
//                [self onSendreqFailed];
//            }
//            //用掉一次后要清除
//            ((AppDelegate*)[UIApplication sharedApplication].delegate).openUserIdList = nil;
//            ((AppDelegate*)[UIApplication sharedApplication].delegate).selectedTicket = nil;
//        } else {
//            BOOL isChat = ([[(AppDelegate*)[UIApplication sharedApplication].delegate chatid] length] > 0);
//            if (isChat) {
//                WWKOpenExistedChatWithMsgReq *req = [[WWKOpenExistedChatWithMsgReq alloc] init];
//                req.attachment = attachment;
//                req.chatId = [(AppDelegate*)[UIApplication sharedApplication].delegate chatid];;
//                req.loginOpenUserid = [(AppDelegate*)[UIApplication sharedApplication].delegate openUserid];
//                if (![WWKApi sendReq:req]) {
//                    [self onSendreqFailed];
//                }
//            } else {
//                WWKSendMessageReq *req = [[WWKSendMessageReq alloc] init];
//                req.attachment = attachment;
//                if (![WWKApi sendReq:req]) {
//                    [self onSendreqFailed];
//                }
//                
//            }
//        }
        
    }
}

/*! @brief 分享文字 */
- (IBAction)shareText:(id)sender {
    
    WWKMessageTextAttachment *attachment = [[WWKMessageTextAttachment alloc] init];
    attachment.text = @"企业微信提供了通讯录管理、应用管理、消息推送、身份验证、移动端SDK、素材、OA数据接口、企业支付、电子发票等API，管理员可以使用这些API，为企业接入更多个性化的办公应用。";
    [self sendMessageToWWK:attachment];
}

/*! @brief 分享小程序 */
- (IBAction)shareWeApp:(id)sender {
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"请输入分享信息" message:nil preferredStyle:(UIAlertControllerStyleAlert)];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"小程序username（带@app后缀）";
        textField.text = @"gh_dde54cb88ce7@app";
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"小程序path, 选填";
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"分享标题，必填";
    }];
    
    __weak typeof(self) weakSelf = self;
    __weak UIAlertController *weakAlert = alertController;
    [alertController addAction:[UIAlertAction actionWithTitle:@"确定" style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
        if ( weakSelf == nil || weakAlert == nil ) {
            return;
        }
        WWKMessageMiniAppAttachment *attachment = [[WWKMessageMiniAppAttachment alloc] init];
        attachment.userName = [weakAlert.textFields objectAtIndex:0].text;
        attachment.path = [weakAlert.textFields objectAtIndex:1].text;
        attachment.hdImageData = UIImageJPEGRepresentation([UIImage imageWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]], 1.0f);
        attachment.title = [weakAlert.textFields objectAtIndex:2].text;
        [weakSelf sendMessageToWWK:attachment];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"取消" style:(UIAlertActionStyleCancel) handler:^(UIAlertAction * _Nonnull action) {
    }]];
    
    [self presentViewController:alertController animated:YES completion:nil];
}

/*! @brief 分享文件 */
- (IBAction)shareFile:(id)sender {
    WWKMessageFileAttachment *attachment = [[WWKMessageFileAttachment alloc] init];
    attachment.filename = @"Download.pdf";
    attachment.path = [[NSBundle mainBundle] pathForResource:@"About Downloads" ofType:@"pdf"];
    [self sendMessageToWWK:attachment];
}

/*! @brief 分享图片 */
- (IBAction)shareImage:(id)sender {
    WWKMessageImageAttachment *attachment = [[WWKMessageImageAttachment alloc] init];
    attachment.filename = @"test.gif";
    attachment.path = [[NSBundle mainBundle] pathForResource:@"test" ofType:@"gif"];
    [self sendMessageToWWK:attachment];
}

/*! @brief 分享小视频 */
- (IBAction)shareVideo:(id)sender {
    WWKMessageVideoAttachment *attachment = [[WWKMessageVideoAttachment alloc] init];
    attachment.filename = @"video.mp4";
    attachment.path = [[NSBundle mainBundle] pathForResource:@"video" ofType:@"mp4"];
    [self sendMessageToWWK:attachment];
}

/*! @brief 分享链接 */
- (IBAction)shareLink:(id)sender {
    WWKMessageLinkAttachment *attachment = [[WWKMessageLinkAttachment alloc] init];
    attachment.title = @"链接标题";
    attachment.summary = @"链接介绍";
    attachment.url = @"http://www.tencent.com";
    attachment.icon = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
    [self sendMessageToWWK:attachment];
}

/*! @brief 分享自定义链接 */
- (IBAction)shareLinkCustom:(id)sender {
    __weak ViewController *weakSelf = self;
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"分享自定义链接" message:nil preferredStyle:(UIAlertControllerStyleAlert)];
    static NSString *linkTitle = @"链接标题";
    static NSString *linkSummary = @"链接介绍";
    static NSString *linkUrl = @"https://magiccube.rtxapp.com/JSapiHandler/index?username=v_haooma&corpid=wwf1407a5d7793ba86&applicationid=1000429";
    [alert addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"链接标题";
        textField.text = linkTitle;
    }];
    [alert addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"链接介绍";
        textField.text = linkSummary;
    }];
    [alert addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"url";
        textField.text = linkUrl;
    }];
    [alert addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"withShareTicket: 0/1（默认0）";
    }];
    [alert addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"ShareTicketState";
    }];
    [alert addAction:[UIAlertAction actionWithTitle:@"取消" style:(UIAlertActionStyleCancel) handler:^(UIAlertAction * _Nonnull action) {
            
    }]];
    __weak UIAlertController *weakAlert = alert;
    [alert addAction:[UIAlertAction actionWithTitle:@"确定" style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
        if ( weakSelf == nil || weakAlert == nil ) {
            return;
        }
        WWKMessageLinkAttachment *attachment = [[WWKMessageLinkAttachment alloc] init];
        linkTitle = weakAlert.textFields[0].text;
        linkSummary = weakAlert.textFields[1].text;
        linkUrl = weakAlert.textFields[2].text;
        attachment.title = linkTitle;
        attachment.summary = linkSummary;
        attachment.url = linkUrl;
        attachment.withShareTicket = weakAlert.textFields[3].text.boolValue;
        attachment.shareTicketState = weakAlert.textFields[4].text;
        attachment.icon = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
        [weakSelf sendMessageToWWK:attachment];
    }]];
    [self presentViewController:alert animated:YES completion:nil];
}

/*! @brief 转发 */
- (IBAction)shareForward:(id)sender {
    WWKMessageGroupAttachment *attachment = [[WWKMessageGroupAttachment alloc] init];
    attachment.title = @"XXX的聊天记录";
    NSMutableArray *array = [NSMutableArray array];

    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小明";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-1000];
        wrapper.avatarUrl = @"http://p.qlogo.cn/bizmail/BDHWBviaRjEgxSn7E5dBwXMM0bibQVVFXe6C6dhtAdsGMu7vL7AuNpIQ/100";
        wrapper.attachment = ({
            WWKMessageTextAttachment *text = [[WWKMessageTextAttachment alloc] init];
            text.text = @"关注你我健康";
            text;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小明";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-950];
        wrapper.avatarUrl = @"http://p.qlogo.cn/bizmail/BDHWBviaRjEgxSn7E5dBwXMM0bibQVVFXe6C6dhtAdsGMu7vL7AuNpIQ/100";
        wrapper.attachment = ({
            WWKMessageImageAttachment *image = [[WWKMessageImageAttachment alloc] init];
            image.filename = @"test.gif";
            image.path = [[NSBundle mainBundle] pathForResource:@"test" ofType:@"gif"];
            image;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小明";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-930];
        wrapper.avatarUrl = @"http://p.qlogo.cn/bizmail/BDHWBviaRjEgxSn7E5dBwXMM0bibQVVFXe6C6dhtAdsGMu7vL7AuNpIQ/100";
        wrapper.attachment = ({
            WWKMessageLocationAttachment *loc = [[WWKMessageLocationAttachment alloc] init];
            loc.title = @"T.I.T创意园";
            loc.address = @"广东省广州市海珠区新港中路397号";
            loc.lat = 23.098837;
            loc.lng = 113.325119;
            loc;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小码";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-900];
        wrapper.avatarData = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
        wrapper.attachment = ({
            WWKMessageTextAttachment *text = [[WWKMessageTextAttachment alloc] init];
            text.text = @"学车找我不愁";
            text;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小码";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-850];
        wrapper.avatarData = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
        wrapper.attachment = ({
            WWKMessageFileAttachment *file = [[WWKMessageFileAttachment alloc] init];
            file.filename = @"Download.pdf";
            file.path = [[NSBundle mainBundle] pathForResource:@"About Downloads" ofType:@"pdf"];
            file;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小码";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-850];
        wrapper.avatarData = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
        wrapper.attachment = ({
            WWKMessageVideoAttachment *video = [[WWKMessageVideoAttachment alloc] init];
            video.filename = @"video.mp4";
            video.path = [[NSBundle mainBundle] pathForResource:@"video" ofType:@"mp4"];
            video;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小码";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-800];
        wrapper.avatarData = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
        wrapper.attachment = ({
            WWKMessageLinkAttachment *link = [[WWKMessageLinkAttachment alloc] init];
            link.title = @"链接标题";
            link.summary = @"链接介绍";
            link.url = @"http://www.tencent.com";
            link.icon = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
            link;
        });
        wrapper;
    })];
    
#ifdef INCLUDE_PRIVATE_API
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"小码";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-800];
        wrapper.avatarData = [NSData dataWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]];
        wrapper.attachment = ({
            WWKMessageMiniProgramAttachment *miniprogram = [[WWKMessageMiniProgramAttachment alloc] init];
            miniprogram.userName = @"gh_d43f693ca31f@app";
            miniprogram.path = @"page/API/index.html";
            miniprogram.hdImageData = UIImageJPEGRepresentation([UIImage imageWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]], 1.0f);
            miniprogram.title = @"分享标题";
            miniprogram.miniProgramType = WWKMessageMiniProgramTypeRelease;
            miniprogram;
        });
        wrapper;
    })];
#endif
    
    attachment.contents = array;
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:@"选择转发类型" message:nil preferredStyle:UIAlertControllerStyleActionSheet];
    [alert addAction:[UIAlertAction actionWithTitle:@"合并转发" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        [self sendMessageToWWK:attachment];
    }]];
    [alert addAction:[UIAlertAction actionWithTitle:@"逐条转发" style:UIAlertActionStyleDefault handler:^(UIAlertAction * _Nonnull action) {
        attachment.forwardType = WWKForwardTypeSplit;
        [self sendMessageToWWK:attachment];
    }]];
    [alert addAction:[UIAlertAction actionWithTitle:@"取消" style:UIAlertActionStyleCancel handler:nil]];
    [self presentViewController:alert animated:YES completion:nil];
}

/*! @brief 分享视频号消息 */
- (IBAction)shareSPHFeed:(id)sender {
//    WWKMessageSPHFeedAttachment *attachment = [[WWKMessageSPHFeedAttachment alloc] init];
//    attachment.feedType = FEED_TYPE_VIDEO;
//    attachment.coverUrl = @"https://www.tencent.com/data/index/index_link_1_3.jpg";
//    attachment.thumbUrl = @"https://www.tencent.com/data/index/index_link_3_2.jpg";
//    attachment.avatar = @"https://www.tencent.com/data/logo-pic/2.2.png";
//    attachment.nickname = @"公开园的鹏哥";
//    attachment.desc = @"连麦张小龙（下）：我更加的了解";
//    attachment.url = @"http://www.tencent.com";
//    attachment.extras = [@"Test" dataUsingEncoding:NSUTF8StringEncoding];
//    [self sendMessageToWWK:attachment];
}

/*! @brief 分享视频号话题 */
- (IBAction)shareSPHTopic:(id)sender {
//    WWKMessageSPHTopicAttachment *attachment = [[WWKMessageSPHTopicAttachment alloc] init];
//    attachment.topicType = TOPIC_TYPE_HASHTAG;
//    attachment.iconUrl = @"https://www.tencent.com/data/logo-pic/4.4.png";
//    attachment.title = @"#音乐会";
//    attachment.desc = @"2964个动态";
//    attachment.url = @"http://www.tencent.com";
//    attachment.extras = [@"Test" dataUsingEncoding:NSUTF8StringEncoding];
//    [self sendMessageToWWK:attachment];
}

/*! @brief 分享视频号名片 */
- (IBAction)shareSPHProfile:(id)sender {
//    WWKMessageSPHProfileAttachment *attachment = [[WWKMessageSPHProfileAttachment alloc] init];
//    attachment.authType = AUTH_TYPE_CORP;
//    attachment.avatar = @"https://www.tencent.com/data/logo-pic/3.3.png";
//    attachment.name = @"80&90歌单长度很长很长";
//    attachment.authJob = @"80&90儿时的回忆，字数还不够再加一些";
//    attachment.authIconUrl = @"https://www.tencent.com/data/logo-pic/3.1.png";
//    attachment.url = @"http://www.tencent.com";
//    attachment.extras = [@"Test" dataUsingEncoding:NSUTF8StringEncoding];
//    [self sendMessageToWWK:attachment];
}

/*! @brief 分享视频号聊天记录 */
- (IBAction)shareSPHCombine:(id)sender {
    WWKMessageGroupAttachment *attachment = [[WWKMessageGroupAttachment alloc] init];
    attachment.title = @"含有视频号消息的聊天记录";
    NSMutableArray *array = [NSMutableArray array];

    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"阿绿";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-1000];
        wrapper.avatarUrl = @"http://mmbiz.qpic.cn/mmemoticon/ajNVdqHZLLCSGzU8cqeRmOjewkFkbWJaw3InQt1FLAopwXUtvvWo921fKpRrFq2Y/0";
        wrapper.attachment = ({
            WWKMessageTextAttachment *text = [[WWKMessageTextAttachment alloc] init];
            text.text = @"我发了一条视频号";
            text;
        });
        wrapper;
    })];
    
    [array addObject:({
        WWKMessageAttachmentWrapper *wrapper = [[WWKMessageAttachmentWrapper alloc] init];
        wrapper.name = @"阿白";
        wrapper.date = [[NSDate date] dateByAddingTimeInterval:-800];
        wrapper.avatarUrl = @"http://mmbiz.qpic.cn/mmemoticon/ajNVdqHZLLDPE4aaDRRPQCmm2KpJzxcKHEZ6fpRQhNJ7IwNrbFjIEmRXTic5RjBJe/0";
//        wrapper.attachment = ({
//            WWKMessageSPHFeedAttachment *feed = [[WWKMessageSPHFeedAttachment alloc] init];
//            feed.feedType = FEED_TYPE_VIDEO;
//            feed.coverUrl = @"https://www.tencent.com/data/index/index_link_1_3.jpg";
//            feed.thumbUrl = @"https://www.tencent.com/data/index/index_link_3_2.jpg";
//            feed.avatar = @"https://www.tencent.com/data/logo-pic/2.2.png";
//            feed.nickname = @"腾讯";
//            feed.desc = @"祝您中秋快乐";
//            feed.url = @"http://www.tencent.com";
//            feed.extras = [@"Test" dataUsingEncoding:NSUTF8StringEncoding];
//            feed;
//        });
        wrapper;
    })];
    
    attachment.contents = array;
    [self sendMessageToWWK:attachment];
}

/*! @brief 选择邮箱联系人 */
- (IBAction)pickContact:(id)sender {
    WWKPickContactReq *req = [[WWKPickContactReq alloc] init];
    req.type = @"mail";
    [WWKApi sendReq:req completionHandler:nil];
}

/*! @brief 选择联系人 */
- (IBAction)pickUsers:(id)sender {
    WWKSelectContactReq *req = [[WWKSelectContactReq alloc] init];
    req.openUserid = [(AppDelegate*)[UIApplication sharedApplication].delegate openUserid];
    [WWKApi sendReq:req completionHandler:nil];
}

/*! @brief 选择联系人 */
- (IBAction)pickUsersV2:(id)sender {
    WWKSelectPrivilegedContactReq *req = [[WWKSelectPrivilegedContactReq alloc] init];
    req.loginOpenUserid = [(AppDelegate*)[UIApplication sharedApplication].delegate openUserid];
    [WWKApi sendReq:req completionHandler:nil];
}

/**
 @brief 腾会响铃选人
 */
- (IBAction)pickUserDialTickt:(id)sender {
    // UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"请输入meetingId"
    //                                                                          message:nil
    //                                                                   preferredStyle:(UIAlertControllerStyleAlert)];
    // [alertController addTextFieldWithConfigurationHandler:^(UITextField *_Nonnull textField) {
    //     textField.text = @"1234567890123456";
    // }];
    // __weak typeof(self) weakSelf = self;
    // __weak UIAlertController *weakAlert = alertController;
    // [alertController addAction:[UIAlertAction actionWithTitle:@"确定"
    //                                                     style:(UIAlertActionStyleDefault)handler:^(UIAlertAction *_Nonnull action) {
    //                                                         if (weakSelf == nil || weakAlert == nil) {
    //                                                             return;
    //                                                         }
    //                                                         NSString *meetingId = [weakAlert.textFields objectAtIndex:0].text;
    //                                                         WWKSelectUserDialTicketReq *req = [[WWKSelectUserDialTicketReq alloc] init];
    //                                                         req.openUserId = [(AppDelegate *)[UIApplication sharedApplication].delegate openUserid];
    //                                                         req.meetingId = meetingId;
    //                                                         [WWKApi sendReq:req];
    //                                                     }]];
    // [alertController addAction:[UIAlertAction actionWithTitle:@"取消"
    //                                                     style:(UIAlertActionStyleCancel)handler:^(UIAlertAction *_Nonnull action) {
    //                                                           }]];
    // [self presentViewController:alertController animated:YES completion:nil];
}
/*! @brief 选择联系人For腾会 */
- (IBAction)pickUsersForTM:(id)sender {
//    WWKTMJSApiTransferReq *req = [[WWKTMJSApiTransferReq alloc] init];
//    NSDictionary *jsonDic = @{@"subfucName":@"AtSelectContact"};
//    NSData *jsonData = [NSJSONSerialization dataWithJSONObject:jsonDic options:0 error:0];
//    NSString *dataStr = [[NSString alloc] initWithData:jsonData encoding:NSUTF8StringEncoding];
//    req.param = dataStr;
//    NSLog(@"%@", req.param);
//    [WWKApi sendReq:req];
}

/*! @brief 无权限案例 */
- (IBAction)noPermission:(id)sender {
    WWKSelectContactReq *req = [[WWKSelectContactReq alloc] init];
    req.openUserid = @"woTD_bDwAAT6zWuw2HRiDP2OGPdGzXjw";
    [WWKApi sendReq:req completionHandler:nil];
}

/*! @brief 自己注册 appid，schema等 */
- (IBAction)sdkRegister:(id)sender {
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"注册应用信息（默认值为JSSDK在线网企业下的一个自建应用）" message:nil preferredStyle:(UIAlertControllerStyleAlert)];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"appId";
        textField.text = @"ww91be2ac93ace2b07";
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"corpId";
        textField.text = @"ww91be2ac93ace2b07";
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"agentId";
        textField.text = @"1000074";
    }];
    
    __weak typeof(self) weakSelf = self;
    __weak UIAlertController *weakAlert = alertController;
    [alertController addAction:[UIAlertAction actionWithTitle:@"确定" style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
        if ( weakSelf == nil || weakAlert == nil ) {
            return;
        }
        NSString *appId = weakAlert.textFields[0].text;
        NSString *corpId = weakAlert.textFields[1].text;
        NSString *agentId = weakAlert.textFields[2].text;
        [WWKApi registerApp:appId corpId:corpId agentId:agentId];
        [weakSelf saveRegisterApp:appId corpId:corpId agentId:agentId];
        [weakSelf setApiTestVersion:WWKApiTestVersionCustomizeApp];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"取消" style:(UIAlertActionStyleCancel) handler:^(UIAlertAction * _Nonnull action) {
    }]];
    
    [self presentViewController:alertController animated:YES completion:nil];
}

- (void)saveRegisterApp:(NSString *)appId corpId:(NSString *)corpId agentId:(NSString *)agentId {
    NSDictionary *dict = @{@"appId" : appId, @"corpId" : corpId, @"agentId" : agentId};
    [[NSUserDefaults standardUserDefaults] setObject:dict forKey:@"regist_app_info"];
    [[NSUserDefaults standardUserDefaults] synchronize];
}

- (void)urlDataSatus {
    NSMutableArray *wxWorkEnables = [NSMutableArray new];
    NSMutableArray *sdkEnables = [NSMutableArray new];
    for(int i = 1;i <= 5;i++){
        BOOL wxwork_use_url_data = [[[NSUserDefaults standardUserDefaults] objectForKey:[NSString stringWithFormat:@"wxwork_enable_url_data_%d",i]] boolValue];
        BOOL sdk_use_url_data = [[[NSUserDefaults standardUserDefaults] objectForKey:[NSString stringWithFormat:@"wxworksdk_enable_url_data_%d",i]] boolValue];
        [wxWorkEnables addObject:@(wxwork_use_url_data)];
        [sdkEnables addObject:@(sdk_use_url_data)];
    }
    
    NSString *message = [NSString stringWithFormat:@"企业微信状态: %@\napp 状态: %@", [wxWorkEnables componentsJoinedByString:@"/"], [sdkEnables componentsJoinedByString:@"/"]];
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"当前app 和企业微信传输之间是否启用 urldata" message:message preferredStyle:(UIAlertControllerStyleAlert)];
    
    __weak typeof(self) weakSelf = self;
    __weak UIAlertController *weakAlert = alertController;
    [alertController addAction:[UIAlertAction actionWithTitle:@"确定" style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
    }]];
    
    [self presentViewController:alertController animated:YES completion:nil];
}


/*! @brief SSO */
- (IBAction)SSO:(id)sender {
//    WWKSSOReq *req = [[WWKSSOReq alloc] init];
//    req.state = @"adfasdfasdf23412341fqw4df14t134rtflajssf8934haioefy";
//    [WWKApi sendReq:req];
//
    UIBarButtonItem *backItem = [[UIBarButtonItem alloc] init];
    backItem.title = @"";
    self.navigationItem.backBarButtonItem = backItem;
    
    [WWKApi startSSOLogin:@"adfasdfasdf23412341fqw4df14t134rtflajssf8934haioefy" fromNavigationController:self.navigationController  completionHandler:nil];
    
}

/*! @brief show logs */
- (IBAction)showLogs:(id)sender {
    
    UIBarButtonItem *backItem = [[UIBarButtonItem alloc] init];
    backItem.title = @"";
    self.navigationItem.backBarButtonItem = backItem;
    
    UIViewController *viewController = [UIViewController new];
    UITextView *textView = [[UITextView alloc] initWithFrame:viewController.view.bounds];
    textView.editable = NO;
    textView.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;
    [viewController.view addSubview:textView];
    textView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    textView.text = [(AppDelegate*)[UIApplication sharedApplication].delegate logs];
    textView.font = [UIFont systemFontOfSize:15];
    viewController.title = @"日志信息";
    [self.navigationController pushViewController:viewController animated:YES];
}


/*! @brief freego */
- (IBAction)setFreeGO:(id)sender {

    UIBarButtonItem *backItem = [[UIBarButtonItem alloc] init];
    backItem.title = @"";
    self.navigationItem.backBarButtonItem = backItem;
    
    UIViewController *viewController = [UIViewController new];
    WKWebView *webView = [[WKWebView alloc] initWithFrame:viewController.view.bounds];
    webView.autoresizingMask = UIViewAutoresizingFlexibleWidth | UIViewAutoresizingFlexibleHeight;
    NSURL *url = [NSURL URLWithString:@"https://open.work.weixin.qq.com/freego"];
    [webView loadRequest:[NSURLRequest requestWithURL:url]];
    [viewController.view addSubview:webView];
    viewController.title = @"设置freego";
    [self.navigationController pushViewController:viewController animated:YES];
    
}

#ifdef INCLUDE_PRIVATE_API
#pragma mark privateApi
- (void)shareWeAppNormal:(id)sender {
    WWKMessageMiniProgramAttachment *attachment = [[WWKMessageMiniProgramAttachment alloc] init];
    attachment.userName = @"gh_d43f693ca31f@app";
    attachment.path = @"page/API/index.html";
    attachment.hdImageData = UIImageJPEGRepresentation([UIImage imageWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]], 1.0f);
    attachment.title = @"分享标题";
    attachment.miniProgramType = WWKMessageMiniProgramTypeRelease;
    [self sendMessageToWWK:attachment];
}

- (void)ShareWeAppPrivateMessage:(id)sender {
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"请输入分享信息" message:nil preferredStyle:(UIAlertControllerStyleAlert)];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"小程序username（带@app后缀）";
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"小程序path, 选填";
    }];
    [alertController addTextFieldWithConfigurationHandler:^(UITextField * _Nonnull textField) {
        textField.placeholder = @"后台分配的activityid，必填";
    }];
    
    __weak typeof(self) weakSelf = self;
    __weak UIAlertController *weakAlert = alertController;
    [alertController addAction:[UIAlertAction actionWithTitle:@"确定" style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
        if ( weakSelf == nil || weakAlert == nil ) {
            return;
        }
        WWKMessageMiniProgramAttachment *attachment = [[WWKMessageMiniProgramAttachment alloc] init];
        attachment.userName = [weakAlert.textFields objectAtIndex:0].text;
        attachment.path = [weakAlert.textFields objectAtIndex:1].text;
        attachment.hdImageData = UIImageJPEGRepresentation([UIImage imageWithContentsOfFile:[[NSBundle mainBundle] pathForResource:@"icon" ofType:@"jpg"]], 1.0f);
        attachment.title = @"分享标题（私密消息）";
        attachment.miniProgramType = WWKMessageMiniProgramTypeRelease;
        attachment.isSecrectMessage = YES;
        NSString *activityId = [weakAlert.textFields objectAtIndex:2].text;
        if ( activityId == nil ) {
            activityId = @"";
        }
        attachment.extraInfoDic = @{
            @"activityId" : activityId,
        };
        [weakSelf sendMessageToWWK:attachment];
    }]];
    [alertController addAction:[UIAlertAction actionWithTitle:@"取消" style:(UIAlertActionStyleCancel) handler:^(UIAlertAction * _Nonnull action) {
    }]];
    
    [self presentViewController:alertController animated:YES completion:nil];
}
#endif

- (void)onSendreqFailed {
    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:@"sendReq failed" message:nil preferredStyle:(UIAlertControllerStyleAlert)];
    [alertController addAction:[UIAlertAction actionWithTitle:@"确定" style:(UIAlertActionStyleDefault) handler:^(UIAlertAction * _Nonnull action) {
        
    }]];
    [self presentViewController:alertController animated:YES completion:nil];
}



@end

@implementation ActionCell

@end
